@@ -8,7 +8,6 @@
 #include "freebusycalendar.h"
 #include "calendarsupport_debug.h"
 
-#include <KCalendarCore/CalFormat>
 #include <KCalendarCore/FreeBusyPeriod>
 #include <KCalendarCore/MemoryCalendar>
 
@@ -21,9 +20,7 @@ using namespace CalendarSupport;
 class CalendarSupport::FreeBusyCalendarPrivate
 {
 public:
-    FreeBusyCalendarPrivate()
-    {
-    }
+    FreeBusyCalendarPrivate() = default;
 
     FreeBusyItemModel *mModel = nullptr;
     KCalendarCore::Calendar::Ptr mCalendar;
@@ -41,7 +38,6 @@ FreeBusyCalendar::FreeBusyCalendar(QObject *parent)
 FreeBusyCalendar::~FreeBusyCalendar()
 {
     qCDebug(CALENDARSUPPORT_LOG) << "deleting" << this;
-    delete d;
 }
 
 KCalendarCore::Calendar::Ptr FreeBusyCalendar::calendar() const
@@ -160,3 +156,5 @@ void FreeBusyCalendar::onRowsChanged(const QModelIndex &topLeft, const QModelInd
         d->mCalendar->endChange(inc);
     }
 }
+
+#include "moc_freebusycalendar.cpp"
