@@ -16,7 +16,7 @@
 #include <KMime/HeaderParsing>
 
 #include <KEmailAddress>
-#include <KIdentityManagement/Identity>
+#include <KIdentityManagementCore/Identity>
 
 #include <KEMailSettings>
 
@@ -108,9 +108,9 @@ void KCalPrefs::fillMailDefaults()
 
 void KCalPrefs::usrRead()
 {
-    KConfigGroup generalConfig(config(), "General");
+    KConfigGroup generalConfig(config(), QStringLiteral("General"));
 
-    KConfigGroup defaultCalendarConfig(config(), "Calendar");
+    KConfigGroup defaultCalendarConfig(config(), QStringLiteral("Calendar"));
     d->mDefaultCalendarId = defaultCalendarConfig.readEntry("Default Calendar", -1);
 
 #if 0
@@ -127,7 +127,7 @@ void KCalPrefs::usrRead()
 
 bool KCalPrefs::usrSave()
 {
-    KConfigGroup generalConfig(config(), "General");
+    KConfigGroup generalConfig(config(), QStringLiteral("General"));
 
 #if 0
     if (mRememberRetrievePw) {
@@ -138,7 +138,7 @@ bool KCalPrefs::usrSave()
     }
 #endif
 
-    KConfigGroup defaultCalendarConfig(config(), "Calendar");
+    KConfigGroup defaultCalendarConfig(config(), QStringLiteral("Calendar"));
     defaultCalendarConfig.writeEntry("Default Calendar", defaultCalendarId());
 
     return KConfigSkeleton::usrSave();
@@ -193,7 +193,7 @@ QStringList KCalPrefs::fullEmails()
     QStringList fullEmails;
 
     // Grab emails from the email identities
-    KIdentityManagement::IdentityManager *idmanager = CalendarSupport::identityManager();
+    KIdentityManagementCore::IdentityManager *idmanager = CalendarSupport::identityManager();
     QStringList lst = idmanager->identities();
 
     fullEmails.reserve(1 + mAdditionalMails.count() + lst.count());
@@ -201,8 +201,8 @@ QStringList KCalPrefs::fullEmails()
     fullEmails << QStringLiteral("%1 <%2>").arg(fullName(), email());
 
     QStringList::Iterator it;
-    KIdentityManagement::IdentityManager::ConstIterator it1;
-    KIdentityManagement::IdentityManager::ConstIterator end1(idmanager->end());
+    KIdentityManagementCore::IdentityManager::ConstIterator it1;
+    KIdentityManagementCore::IdentityManager::ConstIterator end1(idmanager->end());
     for (it1 = idmanager->begin(); it1 != end1; ++it1) {
         fullEmails << (*it1).fullEmailAddr();
     }
@@ -268,3 +268,5 @@ QDateTime KCalPrefs::dayBegins() const
 {
     return d->mDayBegins;
 }
+
+#include "moc_kcalprefs.cpp"
